==> leonardo-0.6b1.tgz: leonardo-0.6b1/bin/create_user.py <==
#!/usr/bin/env python
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

"""
This script is used for creating or modifying users in the user database.
"""

USER_DB = "../data/user_db"

def create_user(name, email, password):
    """
    Creates (or overwrites) a new user entry in the user database.
    """
    
    import anydbm, sha
    user_db = anydbm.open(USER_DB, "c")
    user_db[email] = "%s|%s|%s" % (email, name, sha.sha(password).hexdigest())

from getpass import getpass

if __name__ == "__main__":
    name = raw_input("User's Full Name: ")
    email = raw_input("User's Email Address (used as user id): ")
    while True:
        password = getpass("User's Password: ")
        password_confirm = getpass("Confirm Password: ")
        if password == password_confirm:
            break
        print "Passwords didn't match."

    print "Creating account...",

    create_user(name, email, password)

    print "done."

==> leonardo-0.7b1.tgz: leonardo-0.7b1/bin/create_user.py <==
#!/usr/bin/env python
#
#    Copyright (C) 2003-2005  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

"""
This script is used for creating or modifying users in the user database.
"""

USER_DB = "../data/users"

def create_user(name, email, password):
    """
    Creates (or overwrites) a new user entry in the user database.
    """
    
    import sha
    user_db = file(USER_DB, "a")
    user_db.write("%s:%s:%s\n" % (email, name, sha.sha(password).hexdigest()))

from getpass import getpass

if __name__ == "__main__":
    name = raw_input("User's Full Name: ")
    email = raw_input("User's Email Address (used as user id): ")
    while True:
        password = getpass("User's Password: ")
        password_confirm = getpass("Confirm Password: ")
        if password == password_confirm:
            break
        print "Passwords didn't match."

    print "Creating account...",

    create_user(name, email, password)

    print "done."
